Quotient

Enum Quotient 

pub enum Quotient<T>
where T: Copy + Clone,
{ Nan, Number(T), }
The result of a division

Variants



Nan

Result from division by 0



Number(T)

Numeric value of the quotient

Implementations

Source

impl<T> Quotient<T>
where T: Copy + Clone,

pub fn map<U, F>(self, f: F) -> Quotient<U>
where F: FnOnce(T) -> U, U: Copy + Clone,

Map a Quotient<T> to Quotient<U> by applying a function to a contained value.

pub const fn number(self) -> Option<T>

Convert from Quotient<T> to Option<T>.

pub const fn number_mut(&mut self) -> Option<&mut T>

Convert from &mut Quotient<T> to Option<&mut T>.

pub const fn is_number(self) -> bool

Return true if the quotient is a Number value.

pub const fn is_nan(self) -> bool

Return true if the quotient is a Nan value.

pub fn ok_or<E>(self, err: E) -> Result<T, E>

Transform the Quotient<T> into a Result<T, E>, mapping Number(v) to Ok(v) and Nan to Err(err).

pub fn ok_or_else<E, F>(self, f: F) -> Result<T, E>
where F: FnOnce() -> E,

Transform the Quotient<T> into a Result<T, E>, mapping Number(v) to Ok(v) and Nan to Err(err).

pub fn or(self, other: Self) -> Self

Return the number if not Nan, otherwise returns other.

pub fn or_else<F>(self, f: F) -> Self
where F: FnOnce() -> Self,

Return the number if not Nan, otherwise call f and return the result.

pub fn and<U>(self, other: Quotient<U>) -> Quotient<U>
where U: Copy + Clone,

Return Nan if self is Nan, otherwise return other.

pub fn and_then<U, F>(self, f: F) -> Quotient<U>
where F: FnOnce(T) -> Quotient<U>, U: Copy + Clone,

Return Nan if self is Nan, otherwise call f with the number and return the result.

pub fn xor(self, other: Self) -> Self

Return Number if exactly one of self and other are Number, otherwise return Nan.